@@ -27,7 +27,6 @@ from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import GObject
-import uaclient.api.u.pro.packages.updates.v1 as ua
 
 GdkX11  # pyflakes
 
@@ -37,11 +36,11 @@ warnings.filterwarnings("ignore", "Accessed deprecated property",
 
 import distro_info
 import fnmatch
+import json
 import os
 import subprocess
 import sys
 import time
-import threading
 from gettext import gettext as _
 
 import dbus
@@ -66,7 +65,7 @@ from .Core.AlertWatcher import AlertWatcher
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import get_arch, get_dist, SoftwarePropertiesPage
+from .Core.utils import get_arch, get_dist
 from .backend import (InstallBackend,
                       get_backend)
 
@@ -199,9 +198,9 @@ class UpdateManager(Gtk.Window):
         self._start_pane(None)
         sys.exit(0)
 
-    def show_settings(self, page_number=SoftwarePropertiesPage.updates):
+    def show_settings(self):
         cmd = ["/usr/bin/software-properties-gtk",
-               "--open-tab", str(page_number)]
+               "--open-tab", "2"]
 
         if "WAYLAND_DISPLAY" not in os.environ:
             cmd += ["--toplevel", "%s" % self.get_window().get_xid()]
@@ -271,59 +270,31 @@ class UpdateManager(Gtk.Window):
                and pkg.installed:
                 self.oem_metapackages.add(pkg)
 
-    def _fetch_ua_updates(self):
-        try:
-            self.ua_updates = ua.updates().updates
-        except:
-            self.ua_updates = []
-
     def _get_ua_security_status(self):
         self.ua_security_packages = []
-        self.ua_updates = []
-        t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
-        t.start()
-        while t.is_alive():
-            while Gtk.events_pending():
-                Gtk.main_iteration()
-            time.sleep(0.05)
-        for package in self.ua_updates:
-            if (
-                package.provided_by == 'standard-security'
-                or package.provided_by == 'standard-updates'
-            ):
-                continue
-            status = package.status
-            if (
-                status == 'pending_attach'
-                or status == 'pending_enable'
-                or status == 'upgrade_available'
-            ):
-                name = package.package
-                version = package.version
-                size = package.download_size
-                downloadable = status == 'upgrade_available'
-                self.ua_security_packages.append(
-                    (name, version, size, downloadable)
-                )
-        self.cache.create_pro_cache(self.ua_security_packages)
+        try:
+            p = subprocess.Popen(['ua', 'security-status', '--format=json'],
+                                 stdout=subprocess.PIPE)
+        except OSError:
+            pass
+        else:
+            while p.poll() is None:
+                while Gtk.events_pending():
+                    Gtk.main_iteration()
+                time.sleep(0.05)
+            s = json.load(p.stdout)
+            for package in s.get('packages', []):
+                status = package.get('status', '')
+                if status == 'pending_attach':
+                    name = package.get('name', '')
+                    version = package.get('version', '')
+                    size = package.get('download_size', 0)
+                    self.ua_security_packages.append((name, version, size))
 
     def _make_available_pane(self, install_count, need_reboot=False,
                              cancelled_update=False, error_occurred=False):
         self._check_hwe_support_status()
-        if install_count != 0:
-            header = None
-            desc = None
-            if error_occurred:
-                desc = _("Some software couldn’t be checked for updates.")
-            elif cancelled_update:
-                header = _("You stopped the check for updates.")
-                desc = _("Updated software is available from "
-                         "a previous check.")
-            # Display HWE updates first as an old HWE stack is vulnerable
-            elif self.hwe_replacement_packages:
-                return HWEUpgradeDialog(self)
-            return UpdatesAvailable(self, header, desc, need_reboot)
-        else:
+        if install_count == 0:
             # Need Restart > New Release > No Updates
             if need_reboot:
                 return NeedRestartDialog(self)
@@ -336,6 +307,19 @@ class UpdateManager(Gtk.Window):
                 return HWEUpgradeDialog(self)
             else:
                 return NoUpdatesDialog(self, error_occurred=error_occurred)
+        else:
+            header = None
+            desc = None
+            if error_occurred:
+                desc = _("Some software couldn’t be checked for updates.")
+            elif cancelled_update:
+                header = _("You stopped the check for updates.")
+                desc = _("Updated software is available from "
+                         "a previous check.")
+            # Display HWE updates first as an old HWE stack is vulnerable
+            elif self.hwe_replacement_packages:
+                return HWEUpgradeDialog(self)
+            return UpdatesAvailable(self, header, desc, need_reboot)
 
     def start_error(self, update_and_retry, header, desc):
         if update_and_retry:
